package net.wanji.opt.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.bo.CrossIdAndStartEndDateBO;
import net.wanji.databus.vo.RunningEvaluateCrossListVO;
import net.wanji.opt.bo.CrossNameBO;
import net.wanji.opt.service.impl.RunningEvaluateServiceImpl;
import net.wanji.opt.vo.RunningEvaluateIndexStatusVO;
import net.wanji.opt.vo.RunningEvaluateCrossEvaluateVO;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;
import java.util.List;

/**
 * 运行评价
 *
 * @author Kent HAN
 */
@Api(value = "RunningEvaluateController", description = "运行评价")
@RequestMapping("/runningEvaluate")
@RestController
public class RunningEvaluateController {

    private final RunningEvaluateServiceImpl runningEvaluateService;

    public RunningEvaluateController(RunningEvaluateServiceImpl runningEvaluateService) {
        this.runningEvaluateService = runningEvaluateService;
    }

    @ApiOperation(value = "路口列表", notes = "路口列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/crossList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = RunningEvaluateCrossListVO.class),
    })
    public JsonViewObject crossList(@RequestBody CrossNameBO crossNameBO) {
        List<RunningEvaluateCrossListVO> res = runningEvaluateService.crossList(crossNameBO);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "路口评价", notes = "路口评价", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/crossEvaluate",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = RunningEvaluateCrossEvaluateVO.class),
    })
    public JsonViewObject crossEvaluate(@RequestBody CrossIdAndStartEndDateBO bo) {
        RunningEvaluateCrossEvaluateVO res = runningEvaluateService.crossEvaluate(bo);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "拥堵情况", notes = "拥堵情况", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/congestionStatus",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = RunningEvaluateIndexStatusVO.class),
    })
    public JsonViewObject congestionStatus(@RequestBody CrossIdAndStartEndDateBO bo) {
        List<RunningEvaluateIndexStatusVO> res = runningEvaluateService.congestionStatus(bo);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "失衡情况", notes = "失衡情况", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/unbalanceStatus",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = RunningEvaluateIndexStatusVO.class),
    })
    public JsonViewObject unbalanceStatus(@RequestBody CrossIdAndStartEndDateBO bo) {
        List<RunningEvaluateIndexStatusVO> res = runningEvaluateService.unbalanceStatus(bo);
        return JsonViewObject.newInstance().success(res);
    }

}